BackendData

Struct BackendData 

pub struct BackendData<K: Eq + Hash> {
    pub symbol_table: BiHashMap<String, SymbolId>,
    pub root_elem_table: HashMap<SymbolId, ElemId>,
    pub type_table: HashMap<ElemId, SymbolId>,
    pub bool_table: HashMap<ElemId, bool>,
    pub number_table: HashMap<ElemId, i64>,
    pub string_table: HashMap<ElemId, SymbolId>,
    pub map_table: HashMap<(ElemId, K), ElemId>,
    pub struct_type_table: HashMap<ElemId, SymbolId>,
    pub struct_table: HashMap<(ElemId, SymbolId), ElemId>,
    pub seq_table: HashMap<(ElemId, usize), ElemId>,
    pub variant_type_table: HashMap<ElemId, (SymbolId, SymbolId)>,
    pub tuple_table: HashMap<(ElemId, usize), ElemId>,
}
Table data generated by vector backends.

Fields

symbol_table: BiHashMap<String, SymbolId>root_elem_table: HashMap<SymbolId, ElemId>

Stores root elemets of files.

type_table: HashMap<ElemId, SymbolId>

Stores types of elements. Columns: (elem, elem type)

bool_table: HashMap<ElemId, bool>

Stores values of boolean elements. Columns: (elem, value)

number_table: HashMap<ElemId, i64>

Stores values of number elements. Columns: (elem, value)

string_table: HashMap<ElemId, SymbolId>

Stores values of string elements. Columns: (elem, symbol)

map_table: HashMap<(ElemId, K), ElemId>

Stores map entry facts. Columns: (elem, key, value)

struct_type_table: HashMap<ElemId, SymbolId>

Stores type names of structs. Columns: (elem, struct name)

struct_table: HashMap<(ElemId, SymbolId), ElemId>

Stores struct field facts. Columns: (elem, field name, value elem)

seq_table: HashMap<(ElemId, usize), ElemId>

Stores sequence entry facts. Columns: (elem, index, value)

variant_type_table: HashMap<ElemId, (SymbolId, SymbolId)>

Stores type and variant names of variant elements. (elem, enum name, variant name)

tuple_table: HashMap<(ElemId, usize), ElemId>

Stores tuple entry facts. Columns: (elem, index, value)

Implementations

Source

impl<K: Eq + Hash> BackendData<K>

pub fn dump_with_fn<'a, S>(&'a self, map_key_fn: impl Fn(&'a Self, &'a K) -> S)
where K: 'a, S: 'a + Display,

Print generated fact tables to standard output.

pub fn dump(&self)
where K: Display,

dump function that does not require a printing function for map keys; this can only be called when map key type K implements Display.